@@ -299,10 +299,9 @@ def steering_efforts_test(df, d, t, v_x, angle, torque):
         show_legend=False,
     )
     chart.add('实际数据点', list(zip(df.angle, df.torque)))
-    chart.render_in_browser()
+    # chart.render_in_browser()
 
     return {
-        'df': df,
         'results': (v_average, angle_left_max, angle_right_max,
                     m_max, f_max, w, m_swf, f_swf),
         'chart': chart,
@@ -388,15 +387,16 @@ def draw_lemniscate(radius, width=3.0):
 
 
 @validate_df
-def energy_consumption_test(df, factor, t, current, voltage):
+def energy_consumption_test(df, factor, t, current, voltage, last_only=True):
     """
     根据电压电流和时间，计算能耗
-    @param df:
-    @param factor: 计算功率时乘的系数
-    @param t: 时间列名称，单位s
-    @param current: 电流列名称，单位A
-    @param voltage: 电压列名称，单位V
-    @return:
+    :param df:
+    :param factor: 计算功率时乘的系数
+    :param t: 时间列名称，单位s
+    :param current: 电流列名称，单位A
+    :param voltage: 电压列名称，单位V
+    :param last_only: 是否只返回结果
+    :return:
     """
     # 提取并重命名相关数据列
     df = df[[t, current, voltage]]
@@ -404,12 +404,8 @@ def energy_consumption_test(df, factor, t, current, voltage):
 
     # 计算功率和能耗
     df['power'] = df.current * df.voltage * factor
-    df['consumption'] = get_integral(df[['t', 'power']]) / 3600000
 
-    return {
-        'df': df,
-        'results': (df.consumption.iloc[-1])
-    }
+    return get_integral(df[['t', 'power']], last_only=last_only) / 3600000
 
 
 if __name__ == '__main__':
